@@ -26,9 +26,7 @@
  * USA
  */
 
-#ifdef HAVE_CONFIG_H
 #include <config.h>
-#endif
 
 #include <X11/keysym.h>
 #include <X11/Xmd.h>
@@ -401,28 +399,29 @@ loadprop (int i)
 
   actdata = g_new0 (GkbKeymap, 1);
 
+
   buf = g_strdup_printf (_("name_%d"),i);
-  actdata->name = gkb_load_pref (buf, (i?"Hungarian 105 keys keyboard":"US 105 key keyboard"));
+  actdata->name = gkb_load_pref (buf, (i?"US 105 key keyboard":"Gnome Keyboard default"));
   g_free (buf);
 
   buf = g_strdup_printf (_("label_%d"), i);
-  actdata->label = gkb_load_pref (buf, (i?"hu":"us"));
+  actdata->label = gkb_load_pref (buf, (i?"us":"gkb"));
   g_free (buf);
   
   buf = g_strdup_printf (_("country_%d"), i);
-  actdata->country = gkb_load_pref (buf, (i?"Hungary":"United States"));
+  actdata->country = gkb_load_pref (buf, (i?"United States":"Gnome Keyboard"));
   g_free (buf);
   
   buf = g_strdup_printf (_("lang_%d"), i);
-  actdata->lang = gkb_load_pref (buf, (i?"Hungarian":"English"));
+  actdata->lang = gkb_load_pref (buf, (i?"English":"International"));
   g_free (buf);
   
   buf = g_strdup_printf (("flag_%d"), i);
-  actdata->flag = gkb_load_pref (buf, (i?"hu.png":"us.png"));
+  actdata->flag = gkb_load_pref (buf, (i?"us.png":"gkb.png"));
   g_free (buf);
   
   buf = g_strdup_printf (_("command_%d"), i);
-  actdata->command = gkb_load_pref (buf, (i?"gkb_xmmap hu":"gkb_xmmap us"));
+  actdata->command = gkb_load_pref (buf, (i?"gkb_xmmap us":"xmodmap ~/.gkb_default.xmm"));
   g_free(buf);
 
   actdata->pixbuf = NULL;
@@ -431,6 +430,20 @@ loadprop (int i)
   return actdata;
 }
 
+static void
+do_at_first_run (GKB * gkb) 
+{
+ gboolean firstrun;
+ firstrun = gconf_applet_get_bool (PANEL_APPLET(gkb->applet), 
+                                      "first_run", NULL);
+ if ((firstrun == NULL) || (!firstrun)) {
+  system ("echo \"! This file has generated by Gnome Keyboard applet\" > ~/.gkb_default.xmm");
+  system ("xmodmap -pke >> ~/.gkb_default.xmm");
+  gconf_applet_set_bool (PANEL_APPLET (gkb->applet), "first_run", FALSE, NULL);
+ }
+ 
+}
+
 static void
 load_properties (GKB * gkb)
 {
@@ -443,6 +456,7 @@ load_properties (GKB * gkb)
   gkb->n = gconf_applet_get_int (PANEL_APPLET(gkb->applet), "num", NULL);
 
   gkb->key = gkb_load_pref ("key", "Mod1-Shift_L");
+
   convert_string_to_keysym_state (gkb->key, &gkb->keysym, &gkb->state);
 
   gkb->is_small = gconf_applet_get_bool (PANEL_APPLET(gkb->applet), "small", NULL);
@@ -551,6 +565,7 @@ about_cb (BonoboUIComponent *uic,
   GtkWidget *link;
   gchar *file;	
   GdkPixbuf *pixbuf;
+  GError    *error = NULL;
 
   static const gchar *authors[] = {
 	        "Szabolcs Ban <shooby@gnome.hu>",
@@ -564,20 +579,23 @@ about_cb (BonoboUIComponent *uic,
 	        "Szabolcs Ban <shooby@gnome.hu>",
 		NULL
 	};
-	
 
-  pixbuf = NULL;
-  file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "gkb-icon.png", TRUE, NULL);
-  if (!file) {
-         g_warning (G_STRLOC ": gkb-icon.png cannot be found");
-         pixbuf = gdk_pixbuf_new_from_file (file, NULL);
+  const gchar *translator_credits = _("translator_credits");
+
+  file = gnome_program_locate_file (NULL, GNOME_FILE_DOMAIN_PIXMAP, "gkb-icon.png", FALSE, NULL);
+  pixbuf = gdk_pixbuf_new_from_file (file, &error);
+  g_free (file);
+
+  if (error) {
+         g_warning (G_STRLOC ": cannot open %s: %s", file, error->message);
+         g_error_free (error);
   }
 
-  about = gnome_about_new (_("The GNOME KeyBoard Switcher Applet"),
+  about = gnome_about_new (_("Keyboard Layout Switcher"),
 			   VERSION,
 			   _("(C) 1998-2000 Free Software Foundation"),
                            _("This applet switches between keyboard maps "
-                             "using setxkbmap, or xmodmap.\n"
+                             "using setxkbmap or xmodmap.\n"
                              "Mail me your flag and keyboard layout "
                              "if you want support for your locale "
                              "(my email address is shooby@gnome.hu).\n"
@@ -589,7 +607,7 @@ about_cb (BonoboUIComponent *uic,
                               "\nShooby Ban <shooby@gnome.hu>"),
                             authors,
 			    docauthors,
-			    NULL,
+			    strcmp (translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
 			    pixbuf);
 
   link = gnome_href_new ("http://projects.gnome.hu/gkb",
@@ -598,13 +616,11 @@ about_cb (BonoboUIComponent *uic,
   gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (about)->vbox), link, TRUE,
 		      FALSE, 0);
 
-  gtk_window_set_wmclass (GTK_WINDOW (about), "gkb", "Gkb");
-
-  if (pixbuf) {
-                gtk_window_set_icon (GTK_WINDOW (about), pixbuf);
-                g_object_unref (pixbuf);
-  }
+  if (pixbuf)
+  	g_object_unref (pixbuf);
 
+  gtk_window_set_wmclass (GTK_WINDOW (about), "keyboard layout switcher", "Keyboard Layout Switcher");
+  gnome_window_icon_set_from_file (GTK_WINDOW (about), GNOME_ICONDIR"/gkb.png");
   g_signal_connect (G_OBJECT(about), "destroy",
                           (GCallback)gtk_widget_destroyed, &about);
 
@@ -618,11 +634,8 @@ help_cb (BonoboUIComponent *uic,
          GKB	 *gkb,
          const gchar	 *verbname)
 {
-/* TODO:
-  GnomeHelpMenuEntry help_entry = { "gkb_applet", "index.html" };
-
-  gnome_help_display (NULL, &help_entry);
-*/
+	GError *error = NULL;
+        gnome_help_display("gkb",NULL,&error);
 }
 
 static GdkFilterReturn
@@ -757,6 +770,8 @@ gboolean fill_gkb_applet(PanelApplet *applet)
 			    gdk_screen_height () + 1);
   gtk_widget_show (bah_window);
 
+  do_at_first_run(gkb);
+
   load_properties (gkb);
 
   gkb->keymap = g_list_nth_data (gkb->maps, 0);
@@ -821,7 +836,7 @@ gkb_factory (PanelApplet *applet,
 
 PANEL_APPLET_BONOBO_FACTORY ("OAFIID:GNOME_KeyboardApplet_Factory",
 			     PANEL_TYPE_APPLET,
-                             "GKB_keyboard_layout_switcher",
+                             "gkb",
                              "0",
                              gkb_factory,
                              NULL)
