@@ -1,4 +1,4 @@
-/* $Id: gweather-applet.c,v 1.44 2002/03/12 04:32:55 kevinv Exp $ */
+/* $Id: gweather-applet.c,v 1.46 2002/05/01 21:01:10 kevinv Exp $ */
 
 /*
  *  Papadimitriou Spiros <spapadim+@cs.cmu.edu>
@@ -49,18 +49,16 @@ static void place_widgets (GWeatherApplet *gw_applet)
     
     gtk_container_add (GTK_CONTAINER (gw_applet->applet), gw_applet->box);
     
-    weather_info_get_pixmap_mini(gw_applet->gweather_info, 
-    				 &(gw_applet->applet_pixmap), 
-    				 &(gw_applet->applet_mask));     
-    gw_applet->pixmap = gtk_pixmap_new(gw_applet->applet_pixmap, gw_applet->applet_mask);
-    gtk_box_pack_start (GTK_BOX (gw_applet->box), gw_applet->pixmap, FALSE, FALSE, 0);
+    weather_info_get_pixbuf_mini(gw_applet->gweather_info, 
+    				 &(gw_applet->applet_pixbuf));     
+    gw_applet->image = gtk_image_new_from_pixbuf (gw_applet->applet_pixbuf);
+    gtk_box_pack_start (GTK_BOX (gw_applet->box), gw_applet->image, FALSE, FALSE, 0);
          
     gw_applet->label = gtk_label_new("0\302\260");
     gtk_box_pack_start (GTK_BOX (gw_applet->box), gw_applet->label, FALSE, FALSE, 0);
     
-    gtk_pixmap_set(GTK_PIXMAP(gw_applet->pixmap), 
-    		   gw_applet->applet_pixmap, 
-    		   gw_applet->applet_mask);
+    gtk_image_set_from_pixbuf (GTK_IMAGE (gw_applet->image), 
+    			       gw_applet->applet_pixbuf);
 
     /* Update temperature text */
 
@@ -114,11 +112,8 @@ static void about_cb (BonoboUIComponent *uic, gpointer data, const gchar *verbna
 
 static void help_cb (BonoboUIComponent *uic, gpointer data, const gchar *verbname)
 {
-#ifdef FIXME
-    static GnomeHelpMenuEntry help_entry = { "gweather_applet", "index.html"};
-
-    gnome_help_display(NULL, &help_entry);
-#endif
+    GError *error = NULL;
+    gnome_help_display("gweather",NULL,&error);
 }
 
 static void pref_cb (BonoboUIComponent *uic, gpointer data, const gchar *verbname)
@@ -151,7 +146,7 @@ static const BonoboUIVerb weather_applet_menu_verbs [] = {
 	BONOBO_UI_VERB ("Forecast", forecast_cb),
 	BONOBO_UI_VERB ("Update", update_cb),
         BONOBO_UI_VERB ("Props", pref_cb),
-/*        BONOBO_UI_VERB ("Help", help_cb), */
+        BONOBO_UI_VERB ("Help", help_cb), 
         BONOBO_UI_VERB ("About", about_cb),
 
         BONOBO_UI_VERB_END
@@ -282,12 +277,10 @@ void update_finish (WeatherInfo *info)
     
     gw_applet->gweather_info = info;
    
-    weather_info_get_pixmap_mini(gw_applet->gweather_info, 
-    				 &(gw_applet->applet_pixmap),
-    				 &(gw_applet->applet_mask));
-    gtk_pixmap_set(GTK_PIXMAP(gw_applet->pixmap), 
-    		   gw_applet->applet_pixmap, 
-    		   gw_applet->applet_mask);
+    weather_info_get_pixbuf_mini(gw_applet->gweather_info, 
+    				 &(gw_applet->applet_pixbuf));
+    gtk_image_set_from_pixbuf (GTK_IMAGE (gw_applet->image), 
+    			       gw_applet->applet_pixbuf);
 
     if (gw_applet->gweather_pref.use_metric)
         weather_info_to_metric (gw_applet->gweather_info);
@@ -319,13 +312,11 @@ void gweather_update (GWeatherApplet *gw_applet)
 
     /* Let user know we are updating */
 
-    weather_info_get_pixmap_mini(gw_applet->gweather_info, 
-    				 &(gw_applet->applet_pixmap), 
-    				 &(gw_applet->applet_mask));
+    weather_info_get_pixbuf_mini(gw_applet->gweather_info, 
+    				 &(gw_applet->applet_pixbuf));
 
-    gtk_pixmap_set(GTK_PIXMAP(gw_applet->pixmap), 
-    		   gw_applet->applet_pixmap, 
-    		   gw_applet->applet_mask);
+    gtk_image_set_from_pixbuf (GTK_IMAGE (gw_applet->image), 
+    			       gw_applet->applet_pixbuf);
     gtk_tooltips_set_tip(gw_applet->tooltips, GTK_WIDGET(gw_applet->applet), 
     			 _("Updating..."), NULL);
 
